@@ -1,6 +1,6 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 1998, 1999, 2002, 2003, 2006-2008 Peter Miller
+// Copyright (C) 1998, 1999, 2002, 2003, 2006-2009 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -18,10 +18,10 @@
 
 #include <cctype>
 #include <cstring>
+#include <cstdio>
 #include <cstdlib>
 #include <errno.h>
 #include <iostream>
-using namespace std;
 #include <unistd.h>
 
 #include <lib/arglex.h>
@@ -482,7 +482,7 @@ arglex::token_next()
         //
         {
             bool all_same = true;
-            string possibilities = hit[0]->name;
+            std::string possibilities = hit[0]->name;
             for (int k = 1; k < nhit; ++k)
             {
                 if (hit[0]->token != hit[k]->token)
@@ -511,12 +511,45 @@ arglex::token_next()
         }
         value_string_ = hit[0]->name;
         token = hit[0]->token;
+        check_deprecated(arg);
         break;
     }
     return token;
 }
 
 
+void
+arglex::deprecated_option(const std::string &old_fashioned)
+{
+    deprecated_options.push_back(old_fashioned);
+}
+
+
+void
+arglex::check_deprecated(const std::string &actual)
+    const
+{
+    for
+    (
+        deprecated_options_t::const_iterator it = deprecated_options.begin();
+        it != deprecated_options.end();
+        ++it
+    )
+    {
+        std::string formal = *it;
+        if (compare(formal.c_str(), actual.c_str()))
+        {
+            quit_default.warning
+            (
+                "option \"%s\" is deprecated, use \"%s\" instead",
+                formal.c_str(),
+                token_name(token)
+            );
+        }
+    }
+}
+
+
 const char *
 arglex::token_name(int n)
     const
@@ -566,7 +599,7 @@ arglex::help(const char *name)
         name = progname_get();
     const char *cmd[3] = { "man", name, 0 };
     execvp(cmd[0], (char *const *)cmd);
-    cerr << cmd[0] << ": " << strerror(errno) << endl;
+    std::cerr << cmd[0] << ": " << strerror(errno) << std::endl;
     exit(1);
 }
 
@@ -575,18 +608,20 @@ void
 arglex::version()
     const
 {
-    cout << progname_get() << " version " << version_stamp() << endl;
-    cout << "Copyright (C) " << copyright_years() << " Peter Miller" << endl;
-    cout << endl;
-    cout << "The " << progname_get()
-        << " program comes with ABSOLUTELY NO WARRANTY;" << endl;
-    cout << "for details use the '" << progname_get()
-        << " -LICense' command." << endl;
-    cout << "The " << progname_get()
-        << " program is free software, and you are welcome" << endl;
-    cout << "to redistribute it under certain conditions; for" << endl;
-    cout << "details use the '" << progname_get() << " -LICense' command."
-        << endl;
+    std::cout << progname_get() << " version " << version_stamp() << std::endl;
+    std::cout << "Copyright (C) " << copyright_years() << " Peter Miller"
+        << std::endl;
+    std::cout << std::endl;
+    std::cout << "The " << progname_get()
+        << " program comes with ABSOLUTELY NO WARRANTY;" << std::endl;
+    std::cout << "for details use the '" << progname_get()
+        << " -LICense' command." << std::endl;
+    std::cout << "The " << progname_get()
+        << " program is free software, and you are welcome" << std::endl;
+    std::cout << "to redistribute it under certain conditions; for"
+        << std::endl;
+    std::cout << "details use the '" << progname_get() << " -LICense' command."
+        << std::endl;
     exit(0);
 }
 
@@ -606,25 +641,26 @@ arglex::bad_argument()
     switch (token_cur())
     {
     case token_string:
-        cerr << "misplaced file name (\"" << value_string()
-            << "\") on command line" << endl;
+        std::cerr << "misplaced file name (\"" << value_string()
+            << "\") on command line" << std::endl;
         break;
 
     case token_number:
-        cerr << "misplaced number (" << value_string()
-            << ") on command line" << endl;
+        std::cerr << "misplaced number (" << value_string()
+            << ") on command line" << std::endl;
         break;
 
     case token_option:
-        cerr << "unknown \"" << value_string() << "\" option" << endl;
+        std::cerr << "unknown \"" << value_string() << "\" option" << std::endl;
         break;
 
     case token_eoln:
-        cerr << "command line too short" << endl;
+        std::cerr << "command line too short" << std::endl;
         break;
 
     default:
-        cerr << "misplaced \"" << value_string() << "\" option" << endl;
+        std::cerr << "misplaced \"" << value_string() << "\" option"
+            << std::endl;
         break;
     }
     usage();
@@ -683,11 +719,11 @@ void
 arglex::usage()
     const
 {
-    cerr << "Usage: " << progname_get() << " [ <option>... ] "
-        << usage_tail_get() << endl;
-    cerr << "       " << progname_get() << " -Help" << endl;
-    cerr << "       " << progname_get() << " -VERSion" << endl;
-    cerr << "       " << progname_get() << " -LICense" << endl;
+    std::cerr << "Usage: " << progname_get() << " [ <option>... ] "
+        << usage_tail_get() << std::endl;
+    std::cerr << "       " << progname_get() << " -Help" << std::endl;
+    std::cerr << "       " << progname_get() << " -VERSion" << std::endl;
+    std::cerr << "       " << progname_get() << " -LICense" << std::endl;
     exit(1);
     // NOTREACHED
 }
