@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2002, 2006, 2007 Peter Miller
+//      Copyright (C) 2002, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_CONFIG_MESSY_H
-#define INCLUDE_CONFIG_MESSY_H
+#ifndef LIB_CONFIG_MESSY_H
+#define LIB_CONFIG_MESSY_H
 
 //
 // Make sure Solaris includes POSIX extensions.
@@ -51,4 +51,4 @@
 #define vsnprintf _vsnprintf
 #endif
 
-#endif // INCLUDE_CONFIG_MESSY_H
+#endif // LIB_CONFIG_MESSY_H
