@@ -1,6 +1,6 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 2000-2002, 2006-2008 Peter Miller
+// Copyright (C) 2000-2002, 2006-2009 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -26,15 +26,9 @@
 // See test/01/t0150a.sh for test vectors.
 //
 
+#include <lib/bitrev.h>
 #include <lib/crc16.h>
 
-//
-// The CRC polynomial.  This is used by CCITT and XMODEM, but not X.25
-//
-#define POLYNOMIAL 0x1021
-
-static unsigned short table[256];
-
 //
 // Use a seed of 0xFFFF when augmenting manually (i.e. augmenting by 16
 // zero bits by processing two zero bytes at the end of the data), but a
@@ -50,17 +44,31 @@ static unsigned short const broken_seed = 0x84CF;
 static unsigned short const xmodem_seed = 0;
 
 
-static void
-calculate_table()
+void
+crc16::calculate_table()
 {
-    if (table[1])
-        return;
-    for (unsigned b = 0; b < 256; ++b)
+    if (polynomial == 0)
+        polynomial = polynomial_ccitt;
+    if (bitdir == bit_direction_most_to_least)
     {
-        unsigned short v = b << 8;
-        for (unsigned j = 0; j < 8; ++j)
-            v = (v & 0x8000) ? ((v << 1) ^ POLYNOMIAL) : (v << 1);
-        table[b] = v;
+        for (unsigned b = 0; b < 256; ++b)
+        {
+            unsigned short v = b << 8;
+            for (unsigned j = 0; j < 8; ++j)
+                v = (v & 0x8000) ? ((v << 1) ^ polynomial) : (v << 1);
+            table[b] = v;
+        }
+    }
+    else
+    {
+        polynomial = bitrev16(polynomial);
+        for (unsigned b = 0; b < 256; ++b)
+        {
+            unsigned short v = b;
+            for (unsigned j = 0; j < 8; ++j)
+                v = (v & 1) ? ((v >> 1) ^ polynomial) : (v >> 1);
+            table[b] = v;
+        }
     }
 }
 
@@ -83,28 +91,43 @@ state_from_seed_mode(crc16::seed_mode_t seed_mode)
 }
 
 
-crc16::crc16(seed_mode_t seed_mode, bool aug) :
+crc16::crc16(
+    seed_mode_t seed_mode,
+    bool a_augment,
+    unsigned short a_polynomial,
+    bit_direction_t a_bitdir
+) :
     state(state_from_seed_mode(seed_mode)),
-    augment(aug)
+    augment(a_augment),
+    polynomial(a_polynomial),
+    bitdir(a_bitdir)
 {
     calculate_table();
 }
 
 
-crc16::crc16(const crc16 &arg) :
-    state(arg.state),
-    augment(arg.augment)
+crc16::crc16(const crc16 &rhs) :
+    state(rhs.state),
+    augment(rhs.augment),
+    polynomial(rhs.polynomial),
+    bitdir(rhs.bitdir)
 {
+    for (size_t j = 0; j < 256; ++j)
+        table[j] = rhs.table[j];
 }
 
 
 crc16 &
-crc16::operator=(const crc16 &arg)
+crc16::operator=(const crc16 &rhs)
 {
-    if (this != &arg)
+    if (this != &rhs)
     {
-        state = arg.state;
-        augment = arg.augment;
+        state = rhs.state;
+        augment = rhs.augment;
+        polynomial = rhs.polynomial;
+        bitdir = rhs.bitdir;
+        for (size_t j = 0; j < 256; ++j)
+            table[j] = rhs.table[j];
     }
     return *this;
 }
@@ -122,24 +145,42 @@ crc16::~crc16()
 // validate the two following table-driven implementations.
 //
 
-static unsigned short
-updcrc(unsigned char c, unsigned short state)
+inline unsigned short
+crc16::updcrc(unsigned char c, unsigned short state)
+    const
 {
-    for (unsigned i = 0; i < 8; ++i)
+    if (bitdir == bit_direction_most_to_least)
     {
-        bool xor_flag = !!(state & 0x8000);
-        state <<= 1;
-        if (c & 0x80)
-            state |= 1;
-        if (xor_flag)
-            state ^= POLYNOMIAL;
-        c <<= 1;
+        for (unsigned i = 0; i < 8; ++i)
+        {
+            bool xor_flag = !!(state & 0x8000);
+            state <<= 1;
+            if (c & 0x80)
+                state |= 1;
+            if (xor_flag)
+                state ^= polynomial;
+            c <<= 1;
+        }
+    }
+    else
+    {
+        // note: calculate_table() already reversed the bits in the polynomial
+        for (unsigned i = 0; i < 8; ++i)
+        {
+            bool xor_flag = !!(state & 1);
+            state >>= 1;
+            if (c & 1)
+                state |= 0x8000;
+            if (xor_flag)
+                state ^= polynomial;
+            c >>= 1;
+        }
     }
     return state;
 }
 
 #endif
-
+#if 1
 
 //
 // This version of updcrc doesn't augment automagically, you must
@@ -151,13 +192,21 @@ updcrc(unsigned char c, unsigned short state)
 // for an explanation.
 //
 
-static inline unsigned short
-updcrc(unsigned char c, unsigned short state)
+inline unsigned short
+crc16::updcrc(unsigned char c, unsigned short state)
+    const
 {
-    return ((state << 8) | c) ^ table[state >> 8];
+    if (bitdir == bit_direction_least_to_most)
+    {
+        return (((state >> 8) & 0xFF) | (c << 8)) ^ table[state & 0xFF];
+    }
+    else
+    {
+        return ((state << 8) | c) ^ table[state >> 8];
+    }
 }
 
-
+#endif
 #if 0
 
 //
@@ -171,10 +220,14 @@ updcrc(unsigned char c, unsigned short state)
 // for an explanation.
 //
 
-static inline unsigned short
-updcrc(unsigned char c, unsigned short state)
+inline unsigned short
+crc16::updcrc(unsigned char c, unsigned short state)
+    const
 {
-    return (state << 8) ^ table[(state >> 8) ^ c];
+    if (bitdir == bit_direction_least_to_most)
+        return (state >> 8) ^ table[(state ^ c) & 0xFF];
+    else
+        return (state << 8) ^ table[(state >> 8) ^ c];
 }
 
 #endif
@@ -209,3 +262,41 @@ crc16::get()
     }
     return state;
 }
+
+
+#include <cstdio>
+
+
+void
+crc16::print_table()
+    const
+{
+    printf("/*\n");
+    printf
+    (
+        " * Bit order: %s\n",
+        (
+            bitdir == bit_direction_most_to_least
+        ?
+            "most to least"
+        :
+            "least to most"
+        )
+    );
+    printf(" * Polynomial: 0x");
+    if (bitdir == bit_direction_most_to_least)
+        printf("%04X", polynomial);
+    else
+        printf("%04X", bitrev16(polynomial));
+    printf("\n */\n");
+    printf("const unsigned short table[256] =\n{\n");
+    for (size_t j = 0; j < 256; ++j)
+    {
+        if ((j & 7) == 0)
+            printf("    /* %02X */", int(j));
+        printf(" 0x%04X,", table[j]);
+        if ((j & 7) == 7)
+            printf("\n");
+    }
+    printf("};\n");
+}
