@@ -17,14 +17,12 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_INTERVAL_H
-#define INCLUDE_INTERVAL_H
-
+#ifndef LIB_INTERVAL_H
+#define LIB_INTERVAL_H
 
 #include <stddef.h>
 
 #include <iostream>
-using namespace std;
 
 /**
   * The interval class is used to represent a set of integer values,
@@ -166,7 +164,7 @@ public:
     /**
       * The print method is used to print an interval on an output stream.
       */
-    void print(ostream &) const;
+    void print(std::ostream &) const;
 
     /**
       * The pad method is used to expand an interval by padding each
@@ -185,7 +183,7 @@ public:
       * The representation method is used to manufacture a textural
       * representation of this interval.
       */
-    string representation() const;
+    std::string representation() const;
 
     /**
       * The flatten method is used to convert an interval with holes
@@ -194,6 +192,17 @@ public:
       */
     interval flatten() const;
 
+    /**
+      * The coverage method is used to obtain the size of the interval
+      * in bytes.
+      *
+      * @returns
+      *     The number of bytes cobered by the interval, NOT including
+      *     holes.  Because the result could be 2**32, the 64-bit result
+      *     is used so that this is representable.
+      */
+    long long coverage() const;
+
 private:
     /**
       * The length instance variable is used to remember the length of
@@ -342,11 +351,11 @@ operator - (const interval &arg)
   * The binary left-shift operator is used to print an interval on an
   * output stream.
   */
-inline ostream &
-operator << (ostream &os, const interval &val)
+inline std::ostream &
+operator << (std::ostream &os, const interval &val)
 {
     val.print(os);
     return os;
 }
 
-#endif // INCLUDE_INTERVAL_H
+#endif // LIB_INTERVAL_H
