@@ -17,11 +17,10 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_QUIT_PREFIX_H
-#define INCLUDE_QUIT_PREFIX_H
+#ifndef LIB_QUIT_PREFIX_H
+#define LIB_QUIT_PREFIX_H
 
 #include <string>
-using namespace std;
 #include <lib/quit.h>
 
 /**
@@ -49,7 +48,7 @@ public:
       * messages, once prefixed.  The given string is used as the
       * line prefix.
       */
-    quit_prefix(quit &deeper, const string &prefix);
+    quit_prefix(quit &deeper, const std::string &prefix);
 
     // See base class for documentation.
     virtual void exit(int);
@@ -62,7 +61,7 @@ private:
       * The prefix instance variable is used to remember the line
       * prefix to use.
       */
-    string prefix;
+    std::string prefix;
 
     /**
       * The deepr instance variable is used to remember which handler
@@ -87,4 +86,4 @@ private:
     quit_prefix &operator=(const quit_prefix &);
 };
 
-#endif // INCLUDE_QUIT_PREFIX_H
+#endif // LIB_QUIT_PREFIX_H
