@@ -1,24 +1,23 @@
 //
-//        srecord - manipulate eprom load files
-//        Copyright (C) 1998-2008 Peter Miller
+// srecord - manipulate eprom load files
+// Copyright (C) 1998-2009 Peter Miller
 //
-//        This program is free software; you can redistribute it and/or modify
-//        it under the terms of the GNU General Public License as published by
-//        the Free Software Foundation; either version 3 of the License, or
-//        (at your option) any later version.
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or (at
+// your option) any later version.
 //
-//        This program is distributed in the hope that it will be useful,
-//        but WITHOUT ANY WARRANTY; without even the implied warranty of
-//        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//        GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+// General Public License for more details.
 //
-//        You should have received a copy of the GNU General Public License
-//        along with this program. If not, see
-//        <http://www.gnu.org/licenses/>.
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_ARGLEX_H
-#define INCLUDE_SREC_ARGLEX_H
+#ifndef LIB_SREC_ARGLEX_H
+#define LIB_SREC_ARGLEX_H
 
 #include <lib/arglex.h>
 #include <lib/endian.h>
@@ -38,6 +37,10 @@ public:
     enum
     {
         token_a430 = arglex::token_MAX,
+        token_adler16_be,
+        token_adler16_le,
+        token_adler32_be,
+        token_adler32_le,
         token_and,
         token_aomf,
         token_ascii_hex,
@@ -45,7 +48,9 @@ public:
         token_atmel_generic_be,
         token_atmel_generic_le,
         token_basic_data,
+        token_big,
         token_binary,
+        token_bitrev,
         token_brecord,
         token_byte_swap,
         token_c_array,
@@ -58,6 +63,8 @@ public:
         token_checksum_le_positive,
         token_cl430,
         token_constant,
+        token_constant_be,
+        token_constant_le,
         token_constant_not,
         token_cosmac,
         token_crc16_augment,
@@ -66,11 +73,14 @@ public:
         token_crc16_broken,
         token_crc16_ccitt,
         token_crc16_le,
+        token_crc16_least_to_most,
+        token_crc16_most_to_least,
         token_crc16_xmodem,
         token_crc32_be,
         token_crc32_le,
         token_crop,
         token_dec_binary,
+        token_eeprom,
         token_emon52,
         token_exclude,
         token_exclusive_length,
@@ -85,10 +95,17 @@ public:
         token_fairchild,
         token_fast_load,
         token_fill,
+        token_fletcher16_be,
+        token_fletcher16_le,
+        token_fletcher32_be,
+        token_fletcher32_le,
         token_formatted_binary,
+        token_forth,
         token_four_packed_code,
+        token_gcrypt,
         token_generator,
         token_guess,
+        token_haval,
         token_hexdump,
         token_ignore_checksums,
         token_include,
@@ -99,10 +116,13 @@ public:
         token_length,
         token_length_be,
         token_length_le,
-        token_maximum,
+        token_maximum_address,
         token_maximum_be,
         token_maximum_le,
-        token_minimum,
+        token_md2,
+        token_md5,
+        token_memory_initialization_file,
+        token_minimum_address,
         token_minimum_be,
         token_minimum_le,
         token_minus,
@@ -119,16 +139,23 @@ public:
         token_over,
         token_paren_begin,
         token_paren_end,
+        token_ram,
         token_random,
         token_random_fill,
         token_range_padding,
         token_repeat_data,
         token_repeat_string,
+        token_rmd160,
         token_round_down,
         token_round_nearest,
         token_round_up,
         token_sequence_warnings_disable,
         token_sequence_warnings_enable,
+        token_sha1,
+        token_sha224,
+        token_sha256,
+        token_sha384,
+        token_sha512,
         token_signetics,
         token_spasm_be,
         token_spasm_le,
@@ -141,6 +168,7 @@ public:
         token_style_section,
         token_tektronix,
         token_tektronix_extended,
+        token_tiger,
         token_ti_tagged,
         token_ti_tagged_16,
         token_ti_txt,
@@ -149,6 +177,7 @@ public:
         token_unsplit,
         token_vhdl,
         token_vmem,
+        token_whirlpool,
         token_wilson,
         token_within,
         token_xor,
@@ -228,6 +257,14 @@ public:
       */
     interval get_interval(const char *err_msg_caption);
 
+    /**
+      * The get_interval_small method may be used to parse an interval
+      * set form the command line.  It checks that the interval is
+      * <=1GB, and errors if it is not, with a --big override.  Commonly
+      * used to sanity check things like --fill.
+      */
+    interval get_interval_small(const char *err_msg_caption);
+
     /**
       * The get_string method may be used to get a string from the
       * command line, or issue a fatal error if one is not available.
@@ -401,4 +438,4 @@ private:
     srec_arglex &operator=(const srec_arglex &);
 };
 
-#endif // INCLUDE_SREC_ARGLEX_H
+#endif // LIB_SREC_ARGLEX_H
