@@ -17,16 +17,14 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_H
-#define INCLUDE_SREC_INPUT_H
-
+#ifndef LIB_SREC_INPUT_H
+#define LIB_SREC_INPUT_H
 
 #include <string>
-using namespace std;
 #include <stdarg.h>
 #include <boost/shared_ptr.hpp>
-#include <lib/format_printf.h>
 
+#include <lib/format_printf.h>
 
 class quit; // forward
 class srec_arglex; // forward
@@ -55,7 +53,7 @@ public:
       * of the various record types.
       *
       * Note: there is no guarantee that a header record will appear
-      * first, or that a start address record will appear last.
+      * first, or that a execution start address record will appear last.
       *
       * @param record
       *     Where to put the returned data.
@@ -104,7 +102,7 @@ public:
       * The filename method is used to get the name of the input file
       * being processed.  Derived classes must supply this method.
       */
-    virtual string filename() const = 0;
+    virtual std::string filename() const = 0;
 
     /**
       * The filename_and_line method is used to get the name
@@ -112,7 +110,7 @@ public:
       * implementation simply calls the filename method and returns
       * that.  Text formats should be cleverer.
       */
-    virtual string filename_and_line() const;
+    virtual std::string filename_and_line() const;
 
     /**
       * The get_file_format_name method is used to find out the name
@@ -179,4 +177,4 @@ private:
     srec_input &operator=(const srec_input &);
 };
 
-#endif // INCLUDE_SREC_INPUT_H
+#endif // LIB_SREC_INPUT_H
