@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_FILE_AOMF_H
-#define INCLUDE_SREC_INPUT_FILE_AOMF_H
+#ifndef LIB_SREC_INPUT_FILE_AOMF_H
+#define LIB_SREC_INPUT_FILE_AOMF_H
 
 
 #include <lib/srec/input/file.h>
@@ -45,7 +45,7 @@ private:
       * @param file_name
       *     The name of the file to be read.
       */
-    srec_input_file_aomf(const string &file_name);
+    srec_input_file_aomf(const std::string &file_name);
 
 public:
     /**
@@ -57,7 +57,7 @@ public:
       * @returns
       *     smart pointer to new instance
       */
-    static pointer create(const string &file_name);
+    static pointer create(const std::string &file_name);
 
 protected:
     // See base class for documentation.
@@ -149,4 +149,4 @@ private:
     srec_input_file_aomf &operator=(const srec_input_file_aomf &);
 };
 
-#endif // INCLUDE_SREC_INPUT_FILE_AOMF_H
+#endif // LIB_SREC_INPUT_FILE_AOMF_H
