@@ -42,7 +42,7 @@ private:
       * @param file_name
       *     The name of the file to be read.
       */
-    srec_input_file_brecord(const string &file_name);
+    srec_input_file_brecord(const std::string &file_name);
 
 public:
     /**
@@ -54,7 +54,7 @@ public:
       * @returns
       *     smart pointer to new instance
       */
-    static pointer create(const string &file_name);
+    static pointer create(const std::string &file_name);
 
 protected:
     // See base class for documentation.
