@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_FILE_DEC_BINARY_H
-#define INCLUDE_SREC_INPUT_FILE_DEC_BINARY_H
+#ifndef LIB_SREC_INPUT_FILE_DEC_BINARY_H
+#define LIB_SREC_INPUT_FILE_DEC_BINARY_H
 
 
 #include <lib/srec/input/file.h>
@@ -44,7 +44,7 @@ private:
       * @param file_name
       *     The name of the file to be read.
       */
-    srec_input_file_dec_binary(const string &file_name);
+    srec_input_file_dec_binary(const std::string &file_name);
 
 public:
     /**
@@ -56,7 +56,7 @@ public:
       * @returns
       *     smart pointer to new instance
       */
-    static pointer create(const string &file_name);
+    static pointer create(const std::string &file_name);
 
 protected:
     // See base class for documentation.
@@ -126,4 +126,4 @@ private:
     srec_input_file_dec_binary &operator=(const srec_input_file_dec_binary &);
 };
 
-#endif // INCLUDE_SREC_INPUT_FILE_DEC_BINARY_H
+#endif // LIB_SREC_INPUT_FILE_DEC_BINARY_H
