@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_FILE_EMON52_H
-#define INCLUDE_SREC_INPUT_FILE_EMON52_H
+#ifndef LIB_SREC_INPUT_FILE_EMON52_H
+#define LIB_SREC_INPUT_FILE_EMON52_H
 
 #include <lib/srec/input/file.h>
 
@@ -43,7 +43,7 @@ private:
       * @param file_name
       *     The name of the file to be read.
       */
-    srec_input_file_emon52(const string &file_name);
+    srec_input_file_emon52(const std::string &file_name);
 
 public:
     /**
@@ -55,7 +55,7 @@ public:
       * @returns
       *     smart pointer to new instance
       */
-    static pointer create(const string &file_name);
+    static pointer create(const std::string &file_name);
 
 protected:
     // See base class for documentation.
@@ -88,4 +88,4 @@ private:
     srec_input_file_emon52 &operator=(const srec_input_file_emon52 &);
 };
 
-#endif // INCLUDE_SREC_INPUT_FILE_EMON52_H
+#endif // LIB_SREC_INPUT_FILE_EMON52_H
