@@ -27,7 +27,7 @@ srec_input_file_four_packed_code::~srec_input_file_four_packed_code()
 
 
 srec_input_file_four_packed_code::srec_input_file_four_packed_code(
-        const string &a_file_name) :
+        const std::string &a_file_name) :
     srec_input_file(a_file_name),
     garbage_warning(false),
     seen_some_input(false),
@@ -37,7 +37,7 @@ srec_input_file_four_packed_code::srec_input_file_four_packed_code(
 
 
 srec_input::pointer
-srec_input_file_four_packed_code::create(const string &a_file_name)
+srec_input_file_four_packed_code::create(const std::string &a_file_name)
 {
     return pointer(new srec_input_file_four_packed_code(a_file_name));
 }
@@ -240,7 +240,7 @@ srec_input_file_four_packed_code::read_inner(srec_record &record)
 
     srec_record::type_t type = srec_record::type_data;
     if (length == 0)
-        type = srec_record::type_start_address;
+        type = srec_record::type_execution_start_address;
     record = srec_record(type, address, buffer, length);
     running_address = address + length;
     return 1;
