@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_FILE_FOUR_PACKED_CODE_H
-#define INCLUDE_SREC_INPUT_FILE_FOUR_PACKED_CODE_H
+#ifndef LIB_SREC_INPUT_FILE_FOUR_PACKED_CODE_H
+#define LIB_SREC_INPUT_FILE_FOUR_PACKED_CODE_H
 
 #include <lib/srec/input/file.h>
 
@@ -44,7 +44,7 @@ private:
       * @param file_name
       *     The name of the file to be read.
       */
-    srec_input_file_four_packed_code(const string &file_name);
+    srec_input_file_four_packed_code(const std::string &file_name);
 
 public:
     /**
@@ -56,7 +56,7 @@ public:
       * @returns
       *     smart pointer to new instance
       */
-    static pointer create(const string &file_name);
+    static pointer create(const std::string &file_name);
 
 protected:
     // See base class for documentation.
@@ -142,4 +142,4 @@ private:
             const srec_input_file_four_packed_code &);
 };
 
-#endif // INCLUDE_SREC_INPUT_FILE_FOUR_PACKED_CODE_H
+#endif // LIB_SREC_INPUT_FILE_FOUR_PACKED_CODE_H
