@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 1998-2003, 2005-2008 Peter Miller
+//      Copyright (C) 1998-2003, 2005-2009 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ srec_input_file_intel::~srec_input_file_intel()
 }
 
 
-srec_input_file_intel::srec_input_file_intel(const string &a_file_name) :
+srec_input_file_intel::srec_input_file_intel(const std::string &a_file_name) :
     srec_input_file(a_file_name),
     data_record_count(0),
     garbage_warning(false),
@@ -43,7 +43,7 @@ srec_input_file_intel::srec_input_file_intel(const string &a_file_name) :
 
 
 srec_input::pointer
-srec_input_file_intel::create(const string &a_file_name)
+srec_input_file_intel::create(const std::string &a_file_name)
 {
     return pointer(new srec_input_file_intel(a_file_name));
 }
@@ -174,6 +174,12 @@ srec_input_file_intel::read_inner(srec_record &record)
                 //
                 if (address_field + buffer[0] > (1L << 16))
                 {
+                    //
+                    // If the record would cross a segment boundary,
+                    // wrap around to the beginning of the segment.  We
+                    // do this by using "pushback" to remember additonal
+                    // data.
+                    //
                     int split = (1L << 16) - address_field;
                     pushback =
                         new srec_record
@@ -233,7 +239,7 @@ srec_input_file_intel::read_inner(srec_record &record)
             record =
                 srec_record
                 (
-                    srec_record::type_start_address,
+                    srec_record::type_execution_start_address,
                     address_field,
                     0,
                     0
@@ -270,7 +276,7 @@ srec_input_file_intel::read_inner(srec_record &record)
             record =
                 srec_record
                 (
-                    srec_record::type_start_address,
+                    srec_record::type_execution_start_address,
                     address_field,
                     0,
                     0
@@ -319,11 +325,18 @@ srec_input_file_intel::read(srec_record &record)
                 termination_seen = true;
 #if 0
                 //
-                // We could synthesize a start address, but that means
-                // the input and output don't agree when a round-trip
-                // occurs.
+                // We could synthesize an execution start address, but
+                // that means the input and output don't agree when a
+                // round-trip occurs.
                 //
-                record = srec_record(srec_record::type_start_address, 0, 0, 0);
+                record =
+                    srec_record
+                    (
+                        srec_record::type_execution_start_address,
+                        0,
+                        0,
+                        0
+                    );
                 return true;
 #endif
             }
@@ -354,9 +367,9 @@ srec_input_file_intel::read(srec_record &record)
             }
             break;
 
-        case srec_record::type_start_address:
+        case srec_record::type_execution_start_address:
             if (termination_seen)
-                warning("redundant start address record");
+                warning("redundant execution start address record");
             termination_seen = true;
             break;
         }
