@@ -27,7 +27,8 @@ srec_input_file_intel16::~srec_input_file_intel16()
 }
 
 
-srec_input_file_intel16::srec_input_file_intel16(const string &a_file_name) :
+srec_input_file_intel16::srec_input_file_intel16(
+        const std::string &a_file_name) :
     srec_input_file(a_file_name),
     data_record_count(0),
     garbage_warning(false),
@@ -42,7 +43,7 @@ srec_input_file_intel16::srec_input_file_intel16(const string &a_file_name) :
 
 
 srec_input::pointer
-srec_input_file_intel16::create(const string &a_file_name)
+srec_input_file_intel16::create(const std::string &a_file_name)
 {
     return pointer(new srec_input_file_intel16(a_file_name));
 }
@@ -237,7 +238,7 @@ srec_input_file_intel16::read_inner(srec_record &record)
             record =
                 srec_record
                 (
-                    srec_record::type_start_address,
+                    srec_record::type_execution_start_address,
                     address_field << 1,
                     0,
                     0
@@ -274,7 +275,7 @@ srec_input_file_intel16::read_inner(srec_record &record)
             record =
                 srec_record
                 (
-                    srec_record::type_start_address,
+                    srec_record::type_execution_start_address,
                     address_field << 1,
                     0,
                     0
@@ -336,9 +337,9 @@ srec_input_file_intel16::read(srec_record &record)
             }
             break;
 
-        case srec_record::type_start_address:
+        case srec_record::type_execution_start_address:
             if (termination_seen)
-                warning("redundant start address record");
+                warning("redundant execution start address record");
             termination_seen = true;
             break;
         }
