@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_FILE_SPASM_H
-#define INCLUDE_SREC_INPUT_FILE_SPASM_H
+#ifndef LIB_SREC_INPUT_FILE_SPASM_H
+#define LIB_SREC_INPUT_FILE_SPASM_H
 
 #include <lib/endian.h>
 #include <lib/srec/input/file.h>
@@ -45,7 +45,8 @@ private:
       * @param end
       *     The byte order.
       */
-    srec_input_file_spasm(const string &file_name, endian_t end = endian_big);
+    srec_input_file_spasm(const std::string &file_name,
+        endian_t end = endian_big);
 
 public:
     /**
@@ -60,7 +61,7 @@ public:
       * @returns
       *     smart pointer to new instance
       */
-    static pointer create_be(const string &file_name);
+    static pointer create_be(const std::string &file_name);
 
     /**
       * The create class method is used to create new dynamically
@@ -73,7 +74,7 @@ public:
       * @returns
       *     smart pointer to new instance
       */
-    static pointer create(const string &file_name, endian_t end);
+    static pointer create(const std::string &file_name, endian_t end);
 
 protected:
     // See base class for documentation.
@@ -117,4 +118,4 @@ private:
     srec_input_file_spasm &operator=(const srec_input_file_spasm &);
 };
 
-#endif // INCLUDE_SREC_INPUT_FILE_SPASM_H
+#endif // LIB_SREC_INPUT_FILE_SPASM_H
