@@ -27,7 +27,8 @@ srec_input_file_srecord::~srec_input_file_srecord()
 }
 
 
-srec_input_file_srecord::srec_input_file_srecord(const string &a_file_name) :
+srec_input_file_srecord::srec_input_file_srecord(
+        const std::string &a_file_name) :
     srec_input_file(a_file_name),
     data_count(0),
     garbage_warning(false),
@@ -40,7 +41,7 @@ srec_input_file_srecord::srec_input_file_srecord(const string &a_file_name) :
 
 
 srec_input::pointer
-srec_input_file_srecord::create(const string &a_file_name)
+srec_input_file_srecord::create(const std::string &a_file_name)
 {
     return pointer(new srec_input_file_srecord(a_file_name));
 }
@@ -83,7 +84,13 @@ srec_input_file_srecord::command_line(srec_arglex *cmdln)
             break;
 
         default:
-            fatal_error("address multiple %d not understood", n);
+            fatal_error
+            (
+                "-motorola address multiple %d not understood (do "
+                    "you need parentheses to group the expressions "
+                    "differently?)",
+                n
+            );
             // NOTREACHED
         }
     }
@@ -192,19 +199,19 @@ srec_input_file_srecord::read_inner(srec_record &record)
 
     case 7:
         // termination
-        type = srec_record::type_start_address;
+        type = srec_record::type_execution_start_address;
         naddr = 4;
         break;
 
     case 8:
         // termination
-        type = srec_record::type_start_address;
+        type = srec_record::type_execution_start_address;
         naddr = 3;
         break;
 
     case 9:
         // termination
-        type = srec_record::type_start_address;
+        type = srec_record::type_execution_start_address;
         break;
     }
     if (line_length < naddr)
@@ -243,7 +250,7 @@ srec_input_file_srecord::read(srec_record &record)
                 warning("file contains no data");
             if (!termination_seen)
             {
-                warning("no start address record");
+                warning("no execution start address record");
                 termination_seen = true;
             }
             return false;
@@ -256,7 +263,7 @@ srec_input_file_srecord::read(srec_record &record)
         }
         if
         (
-            record.get_type() != srec_record::type_start_address
+            record.get_type() != srec_record::type_execution_start_address
         &&
             termination_seen
         )
@@ -309,7 +316,7 @@ srec_input_file_srecord::read(srec_record &record)
             }
             continue;
 
-        case srec_record::type_start_address:
+        case srec_record::type_execution_start_address:
             if (record.get_length() > 0)
             {
                 warning("data in termination record ignored");
