@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_INPUT_FILE_SRECORD_H
-#define INCLUDE_INPUT_FILE_SRECORD_H
+#ifndef LIB_INPUT_FILE_SRECORD_H
+#define LIB_INPUT_FILE_SRECORD_H
 
 #include <lib/srec/input/file.h>
 
@@ -42,7 +42,7 @@ private:
       * @param file_name
       *     The name of the file to be read.
       */
-    srec_input_file_srecord(const string &file_name);
+    srec_input_file_srecord(const std::string &file_name);
 
 public:
     /**
@@ -54,7 +54,7 @@ public:
       * @returns
       *     smart pointer to new instance
       */
-    static pointer create(const string &file_name);
+    static pointer create(const std::string &file_name);
 
 protected:
     // See base class for documentation.
@@ -133,4 +133,4 @@ private:
     srec_input_file_srecord &operator=(const srec_input_file_srecord &);
 };
 
-#endif // INCLUDE_INPUT_FILE_SRECORD_H
+#endif // LIB_INPUT_FILE_SRECORD_H
