@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_INPUT_FILE_STEWIE_H
-#define INCLUDE_INPUT_FILE_STEWIE_H
+#ifndef LIB_INPUT_FILE_STEWIE_H
+#define LIB_INPUT_FILE_STEWIE_H
 
 #include <lib/srec/input/file.h>
 
@@ -43,7 +43,7 @@ private:
       * @param file_name
       *     The name of the file to be read.
       */
-    srec_input_file_stewie(const string &file_name);
+    srec_input_file_stewie(const std::string &file_name);
 
 public:
     /**
@@ -55,7 +55,7 @@ public:
       * @returns
       *     smart pointer to new instance
       */
-    static pointer create(const string &file_name);
+    static pointer create(const std::string &file_name);
 
 protected:
     // See base class for documentation.
@@ -123,4 +123,4 @@ private:
     srec_input_file_stewie &operator=(const srec_input_file_stewie &);
 };
 
-#endif // INCLUDE_INPUT_FILE_STEWIE_H
+#endif // LIB_INPUT_FILE_STEWIE_H
