@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 1998-2003, 2005-2008 Peter Miller
+//      Copyright (C) 1998-2003, 2005-2009 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -27,7 +27,8 @@ srec_input_file_tektronix::~srec_input_file_tektronix()
 }
 
 
-srec_input_file_tektronix::srec_input_file_tektronix(const string &a_filename) :
+srec_input_file_tektronix::srec_input_file_tektronix(
+        const std::string &a_filename) :
     srec_input_file(a_filename),
     data_record_count(0),
     garbage_warning(false),
@@ -38,7 +39,7 @@ srec_input_file_tektronix::srec_input_file_tektronix(const string &a_filename) :
 
 
 srec_input::pointer
-srec_input_file_tektronix::create(const string &a_file_name)
+srec_input_file_tektronix::create(const std::string &a_file_name)
 {
     return pointer(new srec_input_file_tektronix(a_file_name));
 }
@@ -94,7 +95,7 @@ srec_input_file_tektronix::read_inner(srec_record &record)
     if (peek_char() == '/')
     {
         //
-        // lines beginning with ``//'' are end-of-file records
+        // lines beginning with "//" are end-of-file records
         //
         seek_to_end();
         return 0;
@@ -142,7 +143,7 @@ srec_input_file_tektronix::read_inner(srec_record &record)
             (
                 buffer[2] == 0
             ?
-                srec_record::type_start_address
+                srec_record::type_execution_start_address
             :
                 srec_record::type_data
             ),
@@ -167,7 +168,7 @@ srec_input_file_tektronix::read(srec_record &record)
                 fatal_error("file contains no data");
             if (!termination_seen)
             {
-                warning("no start address record");
+                warning("no execution start address record");
                 termination_seen = true;
             }
             return false;
@@ -175,7 +176,7 @@ srec_input_file_tektronix::read(srec_record &record)
         seen_some_input = true;
         if
         (
-            record.get_type() != srec_record::type_start_address
+            record.get_type() != srec_record::type_execution_start_address
         &&
             termination_seen
         )
@@ -193,9 +194,9 @@ srec_input_file_tektronix::read(srec_record &record)
             ++data_record_count;
             break;
 
-        case srec_record::type_start_address:
+        case srec_record::type_execution_start_address:
             if (termination_seen)
-                warning("redundant termination record");
+                warning("redundant execution start address record");
             termination_seen = true;
             break;
         }
