@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_FILE_TEKTRONIX_H
-#define INCLUDE_SREC_INPUT_FILE_TEKTRONIX_H
+#ifndef LIB_SREC_INPUT_FILE_TEKTRONIX_H
+#define LIB_SREC_INPUT_FILE_TEKTRONIX_H
 
 #include <lib/srec/input/file.h>
 
@@ -42,7 +42,7 @@ private:
       * @param file_name
       *     The name of the file to be read.
       */
-    srec_input_file_tektronix(const string &file_name);
+    srec_input_file_tektronix(const std::string &file_name);
 
 public:
     /**
@@ -54,7 +54,7 @@ public:
       * @returns
       *     smart pointer to new instance
       */
-    static pointer create(const string &file_name);
+    static pointer create(const std::string &file_name);
 
 protected:
     // See base class for documentation.
@@ -124,4 +124,4 @@ private:
     srec_input_file_tektronix &operator=(const srec_input_file_tektronix &);
 };
 
-#endif // INCLUDE_SREC_INPUT_FILE_TEKTRONIX_H
+#endif // LIB_SREC_INPUT_FILE_TEKTRONIX_H
