@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2000, 2002, 2003, 2006-2008 Peter Miller
+//      Copyright (C) 2000, 2002, 2003, 2006-2009 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ srec_input_file_ti_tagged_16::~srec_input_file_ti_tagged_16()
 
 
 srec_input_file_ti_tagged_16::srec_input_file_ti_tagged_16(
-        const string &a_file_name) :
+        const std::string &a_file_name) :
     srec_input_file(a_file_name),
     address(0),
     csum(0)
@@ -37,7 +37,7 @@ srec_input_file_ti_tagged_16::srec_input_file_ti_tagged_16(
 
 
 srec_input::pointer
-srec_input_file_ti_tagged_16::create(const string &a_file_name)
+srec_input_file_ti_tagged_16::create(const std::string &a_file_name)
 {
     return pointer(new srec_input_file_ti_tagged_16(a_file_name));
 }
@@ -66,7 +66,7 @@ srec_input_file_ti_tagged_16::read(srec_record &record)
         default:
             fatal_error
             (
-                (isprint(c) ? "unknown tag ``%c''" : "unknown tag (%02X)"),
+                (isprint(c) ? "unknown tag '%c'" : "unknown tag (%02X)"),
                 c
             );
 
