@@ -26,7 +26,7 @@ srec_input_file_wilson::~srec_input_file_wilson()
 }
 
 
-srec_input_file_wilson::srec_input_file_wilson(const string &a_file_name) :
+srec_input_file_wilson::srec_input_file_wilson(const std::string &a_file_name) :
     srec_input_file(a_file_name),
     garbage_warning(false),
     seen_some_input(false),
@@ -36,7 +36,7 @@ srec_input_file_wilson::srec_input_file_wilson(const string &a_file_name) :
 
 
 srec_input::pointer
-srec_input_file_wilson::create(const string &a_file_name)
+srec_input_file_wilson::create(const std::string &a_file_name)
 {
     return pointer(new srec_input_file_wilson(a_file_name));
 }
@@ -125,7 +125,7 @@ srec_input_file_wilson::read_inner(srec_record &record)
 
     case '\'':
         // termination
-        type = srec_record::type_start_address;
+        type = srec_record::type_execution_start_address;
         break;
     }
     if (line_length < naddr)
@@ -161,7 +161,7 @@ srec_input_file_wilson::read(srec_record &record)
                         fatal_error("file contains no data");
                 if (!termination_seen)
                 {
-                        warning("no start address record");
+                        warning("no execution start address record");
                         termination_seen = true;
                 }
                 return false;
@@ -169,7 +169,7 @@ srec_input_file_wilson::read(srec_record &record)
         seen_some_input = true;
         if
         (
-                record.get_type() != srec_record::type_start_address
+                record.get_type() != srec_record::type_execution_start_address
         &&
                 termination_seen
         )
@@ -193,14 +193,14 @@ srec_input_file_wilson::read(srec_record &record)
             }
             break;
 
-        case srec_record::type_start_address:
+        case srec_record::type_execution_start_address:
             if (record.get_length() > 0)
             {
-                    warning("data in termination record ignored");
+                    warning("data in execution start address record ignored");
                     record.set_length(0);
             }
             if (termination_seen)
-                    warning("redundant termination record");
+                    warning("redundant execution start address record");
             termination_seen = true;
             break;
         }
