@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_FILTER_H
-#define INCLUDE_SREC_INPUT_FILTER_H
+#ifndef LIB_SREC_INPUT_FILTER_H
+#define LIB_SREC_INPUT_FILTER_H
 
 
 #include <lib/srec/input.h>
@@ -43,10 +43,10 @@ public:
     bool read(class srec_record &record);
 
     // See base class for documentation.
-    string filename() const;
+    std::string filename() const;
 
     // See base class for documentation.
-    string filename_and_line() const;
+    std::string filename_and_line() const;
 
     // See base class for documentation.
     const char *get_file_format_name() const;
@@ -87,4 +87,4 @@ private:
     srec_input_filter &operator=(const srec_input_filter &);
 };
 
-#endif // INCLUDE_SREC_INPUT_FILTER_H
+#endif // LIB_SREC_INPUT_FILTER_H
