@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_FILTER_BYTE_SWAP_H
-#define INCLUDE_SREC_INPUT_FILTER_BYTE_SWAP_H
+#ifndef LIB_SREC_INPUT_FILTER_BYTE_SWAP_H
+#define LIB_SREC_INPUT_FILTER_BYTE_SWAP_H
 
 #include <lib/srec/input/filter.h>
 #include <lib/srec/record.h>
@@ -98,4 +98,4 @@ private:
     srec_input_filter_byte_swap &operator=(const srec_input_filter_byte_swap &);
 };
 
-#endif // INCLUDE_SREC_INPUT_FILTER_BYTE_SWAP_H
+#endif // LIB_SREC_INPUT_FILTER_BYTE_SWAP_H
