@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_FILTER_FILL_H
-#define INCLUDE_SREC_INPUT_FILTER_FILL_H
+#ifndef LIB_SREC_INPUT_FILTER_FILL_H
+#define LIB_SREC_INPUT_FILTER_FILL_H
 
 #include <lib/interval.h>
 #include <lib/srec/input/filter.h>
@@ -101,4 +101,4 @@ private:
     srec_input_filter_fill &operator=(const srec_input_filter_fill &);
 };
 
-#endif // INCLUDE_SREC_INPUT_FILTER_FILL_H
+#endif // LIB_SREC_INPUT_FILTER_FILL_H
