@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2001, 2002, 2006, 2007 Peter Miller
+//      Copyright (C) 2001, 2002, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -22,26 +22,33 @@
 #include <lib/srec/record.h>
 
 
-srec_input_filter_not::srec_input_filter_not(srec_input *arg)
-        : srec_input_filter(arg)
-{
-}
-
-
 srec_input_filter_not::~srec_input_filter_not()
 {
 }
 
 
-int
+srec_input_filter_not::srec_input_filter_not(const srec_input::pointer &arg) :
+    srec_input_filter(arg)
+{
+}
+
+
+srec_input::pointer
+srec_input_filter_not::create(const srec_input::pointer &a_deeper)
+{
+    return pointer(new srec_input_filter_not(a_deeper));
+}
+
+
+bool
 srec_input_filter_not::read(srec_record &record)
 {
         if (!srec_input_filter::read(record))
-                return 0;
+                return false;
         if (record.get_type() == srec_record::type_data)
         {
                 for (int j = 0; j < record.get_length(); ++j)
                         record.set_data(j, ~record.get_data(j));
         }
-        return 1;
+        return true;
 }
