@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_FILTER_OFFSET_H
-#define INCLUDE_SREC_INPUT_FILTER_OFFSET_H
+#ifndef LIB_SREC_INPUT_FILTER_OFFSET_H
+#define LIB_SREC_INPUT_FILTER_OFFSET_H
 
 #include <lib/srec/input/filter.h>
 
@@ -88,4 +88,4 @@ private:
     srec_input_filter_offset &operator=(const srec_input_filter_offset &);
 };
 
-#endif // INCLUDE_SREC_INPUT_FILTER_OFFSET_H
+#endif // LIB_SREC_INPUT_FILTER_OFFSET_H
