@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_FILTER_OR_H
-#define INCLUDE_SREC_INPUT_FILTER_OR_H
+#ifndef LIB_SREC_INPUT_FILTER_OR_H
+#define LIB_SREC_INPUT_FILTER_OR_H
 
 #include <lib/srec/input/filter.h>
 
@@ -86,4 +86,4 @@ private:
     srec_input_filter_or &operator=(const srec_input_filter_or &);
 };
 
-#endif // INCLUDE_SREC_INPUT_FILTER_OR_H
+#endif // LIB_SREC_INPUT_FILTER_OR_H
