@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2004, 2006, 2007 Peter Miller
+//      Copyright (C) 2004, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,31 +17,38 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
 #include <lib/interval.h>
 #include <lib/r250.h>
 #include <lib/srec/input/filter/random_fill.h>
 #include <lib/srec/record.h>
 
 
-srec_input_filter_random_fill::srec_input_filter_random_fill(srec_input *a1,
-        const interval &a3) :
-    srec_input_filter(a1),
-    range(a3)
-{
-}
-
-
 srec_input_filter_random_fill::~srec_input_filter_random_fill()
 {
 }
 
 
-int
+srec_input_filter_random_fill::srec_input_filter_random_fill(
+        const srec_input::pointer &a1, const interval &a3) :
+    srec_input_filter(a1),
+    range(a3)
+{
+}
+
+
+srec_input::pointer
+srec_input_filter_random_fill::create(const srec_input::pointer &a_deeper,
+    const interval &a_range)
+{
+    return pointer(new srec_input_filter_random_fill(a_deeper, a_range));
+}
+
+
+bool
 srec_input_filter_random_fill::generate(srec_record &record)
 {
     if (range.empty())
-        return 0;
+        return false;
     unsigned char buffer[srec_record::max_data_length];
     interval chunk(range.get_lowest(), range.get_lowest() + sizeof(buffer));
     chunk *= range;
@@ -58,11 +65,11 @@ srec_input_filter_random_fill::generate(srec_record &record)
             nbytes
         );
     range -= chunk;
-    return 1;
+    return true;
 }
 
 
-int
+bool
 srec_input_filter_random_fill::read(srec_record &record)
 {
     if (!srec_input_filter::read(record))
@@ -76,5 +83,5 @@ srec_input_filter_random_fill::read(srec_record &record)
                 record.get_address() + record.get_length()
             );
     }
-    return 1;
+    return true;
 }
