@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 1998, 1999, 2001, 2002, 2006, 2007 Peter Miller
+//      Copyright (C) 1998, 1999, 2001, 2002, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,13 +17,17 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
 #include <lib/srec/input/filter/split.h>
 #include <lib/srec/record.h>
 
 
-srec_input_filter_split::srec_input_filter_split(srec_input *a1, int a2, int a3,
-        int a4) :
+srec_input_filter_split::~srec_input_filter_split()
+{
+}
+
+
+srec_input_filter_split::srec_input_filter_split(const srec_input::pointer &a1,
+        int a2, int a3, int a4) :
     srec_input_filter(a1),
     modulus(a2),
     offset(a2 - a3),
@@ -39,12 +43,15 @@ srec_input_filter_split::srec_input_filter_split(srec_input *a1, int a2, int a3,
 }
 
 
-srec_input_filter_split::~srec_input_filter_split()
+srec_input::pointer
+srec_input_filter_split::create(const srec_input::pointer &a_deeper,
+    int a2, int a3, int a4)
 {
+    return pointer(new srec_input_filter_split(a_deeper, a2, a3, a4));
 }
 
 
-int
+bool
 srec_input_filter_split::read(srec_record &record)
 {
     for (;;)
@@ -57,11 +64,11 @@ srec_input_filter_split::read(srec_record &record)
         )
         {
             if (!srec_input_filter::read(buffer))
-                return 0;
+                return false;
             if (buffer.get_type() != srec_record::type_data)
             {
                 record = buffer;
-                return 1;
+                return true;
             }
             buffer_pos = 0;
         }
@@ -82,7 +89,7 @@ srec_input_filter_split::read(srec_record &record)
             //
             addr = (addr / modulus - 1) * width + phase;
             record = srec_record(srec_record::type_data, addr, &c, 1);
-            return 1;
+            return true;
         }
         ++buffer_pos;
     }
