@@ -21,8 +21,13 @@
 #include <lib/srec/input/filter/unfill.h>
 
 
-srec_input_filter_unfill::srec_input_filter_unfill(srec_input *a1, int a2,
-        int a3) :
+srec_input_filter_unfill::~srec_input_filter_unfill()
+{
+}
+
+
+srec_input_filter_unfill::srec_input_filter_unfill(
+        const srec_input::pointer &a1, int a2, int a3) :
     srec_input_filter(a1),
     fill_value(a2),
     fill_minimum(a3),
@@ -32,12 +37,15 @@ srec_input_filter_unfill::srec_input_filter_unfill(srec_input *a1, int a2,
 }
 
 
-srec_input_filter_unfill::~srec_input_filter_unfill()
+srec_input::pointer
+srec_input_filter_unfill::create(const srec_input::pointer &a_deeper, int a2,
+    int a3)
 {
+    return pointer(new srec_input_filter_unfill(a_deeper, a2, a3));
 }
 
 
-int
+bool
 srec_input_filter_unfill::read(srec_record &record)
 {
     for (;;)
@@ -50,11 +58,11 @@ srec_input_filter_unfill::read(srec_record &record)
         )
         {
             if (!srec_input_filter::read(buffer))
-                return 0;
+                return false;
             if (buffer.get_type() != srec_record::type_data)
             {
                 record = buffer;
-                return 1;
+                return true;
             }
             buffer_pos = 0;
         }
@@ -87,7 +95,7 @@ srec_input_filter_unfill::read(srec_record &record)
                         buffer.get_data() + first_pos,
                         buffer_pos - first_pos
                     );
-                return 1;
+                return true;
             }
         }
         else
@@ -110,7 +118,7 @@ srec_input_filter_unfill::read(srec_record &record)
                     buffer.get_data() + first_pos,
                     buffer_pos - first_pos
                 );
-            return 1;
+            return true;
         }
     }
 }
