@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_FILTER_UNFILL_H
-#define INCLUDE_SREC_INPUT_FILTER_UNFILL_H
+#ifndef LIB_SREC_INPUT_FILTER_UNFILL_H
+#define LIB_SREC_INPUT_FILTER_UNFILL_H
 
 #include <lib/srec/input/filter.h>
 #include <lib/srec/record.h>
@@ -119,4 +119,4 @@ private:
     srec_input_filter_unfill &operator=(const srec_input_filter_unfill &);
 };
 
-#endif // INCLUDE_SREC_INPUT_FILTER_UNFILL_H
+#endif // LIB_SREC_INPUT_FILTER_UNFILL_H
