@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_INPUT_FILTER_UNSPLIT_H
-#define INCLUDE_SREC_INPUT_FILTER_UNSPLIT_H
+#ifndef LIB_SREC_INPUT_FILTER_UNSPLIT_H
+#define LIB_SREC_INPUT_FILTER_UNSPLIT_H
 
 #include <lib/srec/input/filter.h>
 #include <lib/srec/record.h>
@@ -127,4 +127,4 @@ private:
     srec_input_filter_unsplit &operator=(const srec_input_filter_unsplit &);
 };
 
-#endif // INCLUDE_SREC_INPUT_FILTER_UNSPLIT_H
+#endif // LIB_SREC_INPUT_FILTER_UNSPLIT_H
