@@ -50,7 +50,7 @@ public:
 
 protected:
     // See base class for documentation.
-    string filename() const;
+    std::string filename() const;
 
     // See base class for documentation.
     const char *get_file_format_name() const;
