@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 1998, 1999, 2002, 2003, 2006, 2007 Peter Miller
+//      Copyright (C) 1998, 1999, 2002, 2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 
 
 interval
-srec_input_interval(srec_input *ifp)
+srec_input_interval(srec_input::pointer ifp)
 {
     interval range;
     srec_record record;
