@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 1998, 1999, 2001-2003, 2006, 2007 Peter Miller
+//      Copyright (C) 1998, 1999, 2001-2003, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -66,7 +66,7 @@ srec_memory_chunk::set(unsigned long offset, int datum)
 
 
 void
-srec_memory_chunk::walk(srec_memory_walker *w)
+srec_memory_chunk::walk(srec_memory_walker::pointer w)
     const
 {
     for (int j = 0; j < size; ++j)
