@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_MEMORY_WALKER_H
-#define INCLUDE_SREC_MEMORY_WALKER_H
+#ifndef LIB_SREC_MEMORY_WALKER_H
+#define LIB_SREC_MEMORY_WALKER_H
 
 #include <boost/shared_ptr.hpp>
 
@@ -61,7 +61,7 @@ public:
 
     /**
       * The observe_start_address method is used to inform the walker
-      * of the start address record.  The default does nothing.
+      * of the execution start address record.  The default does nothing.
       */
     virtual void observe_start_address(const srec_record * = 0);
 
@@ -83,4 +83,4 @@ private:
     srec_memory_walker &operator=(const srec_memory_walker &);
 };
 
-#endif // INCLUDE_SREC_MEMORY_WALKER_H
+#endif // LIB_SREC_MEMORY_WALKER_H
