@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_MEMORY_WALKER_CONTINUITY_H
-#define INCLUDE_SREC_MEMORY_WALKER_CONTINUITY_H
+#ifndef LIB_SREC_MEMORY_WALKER_CONTINUITY_H
+#define LIB_SREC_MEMORY_WALKER_CONTINUITY_H
 
 #include <lib/srec/memory/walker.h>
 
@@ -82,4 +82,4 @@ private:
         const srec_memory_walker_continuity &);
 };
 
-#endif // INCLUDE_SREC_MEMORY_WALKER_CONTINUITY_H
+#endif // LIB_SREC_MEMORY_WALKER_CONTINUITY_H
