@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2000-2002, 2006, 2007 Peter Miller
+//      Copyright (C) 2000-2002, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,21 +17,29 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-
 #include <lib/srec/memory/walker/crc32.h>
 #include <lib/srec/output.h>
 
 
-srec_memory_walker_crc32::srec_memory_walker_crc32()
+srec_memory_walker_crc32::~srec_memory_walker_crc32()
 {
 }
 
 
-srec_memory_walker_crc32::~srec_memory_walker_crc32()
+srec_memory_walker_crc32::srec_memory_walker_crc32(
+        crc32::seed_mode_t seed_mode) :
+    checksum(seed_mode)
 {
 }
 
 
+srec_memory_walker_crc32::pointer
+srec_memory_walker_crc32::create(crc32::seed_mode_t seed_mode)
+{
+    return pointer(new srec_memory_walker_crc32(seed_mode));
+}
+
+
 void
 srec_memory_walker_crc32::observe(unsigned long, const void *data, int length)
 {
