@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_MEMORY_WALKER_CRC32_H
-#define INCLUDE_SREC_MEMORY_WALKER_CRC32_H
+#ifndef LIB_SREC_MEMORY_WALKER_CRC32_H
+#define LIB_SREC_MEMORY_WALKER_CRC32_H
 
 #include <lib/crc32.h>
 #include <lib/srec/memory/walker.h>
@@ -86,4 +86,4 @@ private:
     srec_memory_walker_crc32 &operator=(const srec_memory_walker_crc32 &);
 };
 
-#endif // INCLUDE_SREC_MEMORY_WALKER_CRC32_H
+#endif // LIB_SREC_MEMORY_WALKER_CRC32_H
