@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 1998, 1999, 2001-2003, 2006-2008 Peter Miller
+//      Copyright (C) 1998, 1999, 2001-2003, 2006-2009 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_H
-#define INCLUDE_SREC_OUTPUT_H
+#ifndef LIB_SREC_OUTPUT_H
+#define LIB_SREC_OUTPUT_H
 
 #include <cstdarg>
 #include <string>
@@ -65,12 +65,12 @@ public:
     virtual void write_data(unsigned long, const void *, size_t);
 
     /**
-      * The write_start_address method is used to write a start
-      * address record to the output.  If no record is specified,
-      * a default record will be supplied.      The write method will
-      * be called.
+      * The write_execution_start_address method is used to write an
+      * execution start address record to the output.  If no record is
+      * specified, a default record will be supplied.  The write method
+      * will be called.
       */
-    virtual void write_start_address(const srec_record * = 0);
+    virtual void write_execution_start_address(const srec_record * = 0);
 
     /**
       * The set_line_length method is used to set the maximum
@@ -160,6 +160,9 @@ public:
       * of the upper bound (highest address plus one) of the output
       * to come.  Shall be called before the hread or any data records
       * are written.
+      *
+      * @param addr
+      *     One past the highest used memory byte.
       */
     virtual void notify_upper_bound(unsigned long addr);
 
@@ -193,4 +196,4 @@ private:
     srec_output &operator=(const srec_output &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_H
+#endif // LIB_SREC_OUTPUT_H
