@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_H
-#define INCLUDE_SREC_OUTPUT_FILE_H
+#ifndef LIB_SREC_OUTPUT_FILE_H
+#define LIB_SREC_OUTPUT_FILE_H
 
 #include <string>
 #include <lib/srec/output.h>
@@ -57,18 +57,73 @@ public:
     virtual const std::string filename() const;
 
     /**
-      * Call this method if you want the output to contain only data
-      * records.  No header records or start address records (or any
-      * other records) will be emitted.
+      * The enable_header class method is used to enable or disable
+      * the writing of header records into output file, if the format
+      * supports optional header records.
+      *
+      * @param yesno
+      *     true if header records should be written, false if not
       */
-    static void data_only();
+    static void enable_header(bool yesno);
 
     /**
-      * The crlf method is used to force CRLF line termination, event if
-      * the current operating system's native text files use something
-      * else.
+      * The enable_data_count class method is used to enable or disable
+      * the writing of data record count records into output file, if
+      * the format supports optional data record count records.
+      *
+      * @param yesno
+      *     true if data record count records should be written, false
+      *     if not
       */
-    static void crlf();
+    static void enable_data_count(bool yesno);
+
+    /**
+      * The enable_goto_addr class method is used to enable or disable
+      * the writing of execution start address records into output file,
+      * if the format supports optional excution start address records.
+      *
+      * @param yesno
+      *     true if execution start address records should be written,
+      *     false if not
+      */
+    static void enable_goto_addr(bool yesno);
+
+    /**
+      * The enable_footer class method is used to enable or disable
+      * the writing of footer records into output file, if the format
+      * supports optional footer records.
+      *
+      * @param yesno
+      *     true if footer records should be written, false if not
+      */
+    static void enable_footer(bool yesno);
+
+    /**
+      * The enable_by_name class method is used to enable or disable
+      * the writing of various records into output file.
+      *
+      * @param name
+      *     the name of the record type to enable or disable
+      * @param yesno
+      *     true if should be enable, false if sjould be disabled
+      * @returns
+      *     true if name understood, false if not (to trigger diagnostic
+      *     error message)
+      */
+    static bool enable_by_name(const std::string &name, bool yesno);
+
+    /**
+      * The line_termination_by_name method is used to force line
+      * termination to a particular style, rather than the current
+      * operating system's native text format.
+      *
+      * @param name
+      *     The name of the line termination style to be used,
+      *     e.g. "crlf" or "nl".
+      * @returns
+      *     true if successful, false if name unknown
+      */
+    static bool line_termination_by_name(const std::string &name);
 
 protected:
     /**
@@ -184,26 +239,59 @@ protected:
     void put_stringf(const char *, ...)             FORMAT_PRINTF(2, 3);
 
     /**
-      * The mode method returns a suitable mode for passing to fopen.
-      * The default implementation returns "w+" but derived classes may
-      * over-ride it (e.g. "wb" for binary).
+      * The enable_header_flag class variable is set by the
+      * enable_header() method, to remember whether or not header
+      * records are to be emitted (if the format supports optional
+      * header records).
       */
-    virtual const char *mode() const;
+    static bool enable_header_flag;
 
     /**
-      * The data_only_flag class variable is set by the data_only()
-      * method, to remember that only data records are to be sent to the
-      * output.  Header records, start address records, etc, are all
-      * suppressed.
+      * The enable_data_count_flag class variable is set by the
+      * enable_data_count() method, to remember whether or not data
+      * record count records are to be emitted (if the format supports
+      * optional data record count records).
       */
-    static bool data_only_flag;
+    static bool enable_data_count_flag;
 
     /**
-      * The crlf_flag class variable is used to remember whether or not
-      * to force CRLF line termination, event if the current operating
-      * system's native text files use something else.
+      * The enable_exec_goto_flag class variable is set by the
+      * enable_exec_goto() method, to remember whether or not execution
+      * start address records are to be emitted (if the format supports
+      * optional execution start address records).
       */
-    static bool crlf_flag;
+    static bool enable_goto_addr_flag;
+
+    /**
+      * The enable_footer_flag class variable is set by the
+      * enable_footer() method, to remember whether or not footer
+      * records (end-of-file record) are to be emitted (if the format
+      * supports optional footer records).
+      */
+    static bool enable_footer_flag;
+
+    enum line_termination_t
+    {
+        line_termination_native,
+        line_termination_crlf,
+        line_termination_nl,
+        line_termination_binary = line_termination_nl,
+        line_termination_cr,
+        line_termination_primos
+    };
+
+    /**
+      * The line_termination class variable is used to remember the
+      * desired line termination style.  Defaults to the native style of
+      * the current operating system.
+      */
+    static line_termination_t line_termination;
+
+    /**
+      * The line_termination_guess class method i sused to figure out
+      * the line termination style of the host environment.
+      */
+    static line_termination_t line_termination_guess();
 
 private:
     /**
@@ -294,4 +382,4 @@ private:
     srec_output_file &operator=(const srec_output_file &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_H
+#endif // LIB_SREC_OUTPUT_FILE_H
