@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_AOMF_H
-#define INCLUDE_SREC_OUTPUT_FILE_AOMF_H
+#ifndef LIB_SREC_OUTPUT_FILE_AOMF_H
+#define LIB_SREC_OUTPUT_FILE_AOMF_H
 
 #include <lib/srec/output/file.h>
 
@@ -69,9 +69,6 @@ protected:
     // See base class for documentation.
     void address_length_set(int);
 
-    // See base class for documentation.
-    const char *mode() const;
-
     // See base class for documentation.
     const char *format_name() const;
 
@@ -140,4 +137,4 @@ private:
     srec_output_file_aomf &operator=(const srec_output_file_aomf &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_AOMF_H
+#endif // LIB_SREC_OUTPUT_FILE_AOMF_H
