@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_ASCII_HEX_H
-#define INCLUDE_SREC_OUTPUT_FILE_ASCII_HEX_H
+#ifndef LIB_SREC_OUTPUT_FILE_ASCII_HEX_H
+#define LIB_SREC_OUTPUT_FILE_ASCII_HEX_H
 
 #include <lib/srec/output/file.h>
 
@@ -138,4 +138,4 @@ private:
     srec_output_file_ascii_hex &operator=(const srec_output_file_ascii_hex &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_ASCII_HEX_H
+#endif // LIB_SREC_OUTPUT_FILE_ASCII_HEX_H
