@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_ASM_H
-#define INCLUDE_SREC_OUTPUT_FILE_ASM_H
+#ifndef LIB_SREC_OUTPUT_FILE_ASM_H
+#define LIB_SREC_OUTPUT_FILE_ASM_H
 
 #include <lib/srec/output/file.h>
 #include <lib/interval.h>
@@ -43,7 +43,7 @@ private:
       * @param file_name
       *     The name of the file to be written.
       */
-    srec_output_file_asm(const string &file_name);
+    srec_output_file_asm(const std::string &file_name);
 
 public:
     /**
@@ -80,7 +80,7 @@ private:
       * The prefix instance variable is used to remember the variable
       * name prefix to be used in the output.
       */
-    string prefix;
+    std::string prefix;
 
     /**
       * The taddr instance variabel is used to remember the
@@ -192,4 +192,4 @@ private:
     srec_output_file_asm &operator=(const srec_output_file_asm &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_ASM_H
+#endif // LIB_SREC_OUTPUT_FILE_ASM_H
