@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 2001, 2002, 2006, 2007 Peter Miller
+//      Copyright (C) 2001, 2002, 2006-2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -21,19 +21,27 @@
 #include <lib/srec/record.h>
 
 
-srec_output_file_atmel_generic::srec_output_file_atmel_generic(
-        const std::string &a_file_name, bool endianness) :
-    srec_output_file(a_file_name),
-    bigend(endianness)
+srec_output_file_atmel_generic::~srec_output_file_atmel_generic()
 {
 }
 
 
-srec_output_file_atmel_generic::~srec_output_file_atmel_generic()
+srec_output_file_atmel_generic::srec_output_file_atmel_generic(
+        const std::string &a_file_name, endian_t a_end) :
+    srec_output_file(a_file_name),
+    end(a_end)
 {
 }
 
 
+srec_output::pointer
+srec_output_file_atmel_generic::create(const std::string &a_file_name,
+    endian_t a_end)
+{
+    return pointer(new srec_output_file_atmel_generic(a_file_name, a_end));
+}
+
+
 void
 srec_output_file_atmel_generic::write(const srec_record &record)
 {
@@ -58,7 +66,7 @@ srec_output_file_atmel_generic::write(const srec_record &record)
     {
         put_3bytes(address / 2);
         put_char(':');
-        if (bigend)
+        if (end == endian_big)
         {
             put_byte(record.get_data(j + 1));
             put_byte(record.get_data(j));
