@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_BINARY_H
-#define INCLUDE_SREC_OUTPUT_FILE_BINARY_H
+#ifndef LIB_SREC_OUTPUT_FILE_BINARY_H
+#define LIB_SREC_OUTPUT_FILE_BINARY_H
 
 #include <lib/srec/output/file.h>
 
@@ -68,9 +68,6 @@ protected:
     // See base class for documentation.
     int preferred_block_size_get() const;
 
-    // See base class for documentation.
-    const char *mode() const;
-
     // See base class for documentation.
     const char *format_name() const;
 
@@ -91,4 +88,4 @@ private:
     srec_output_file_binary &operator=(const srec_output_file_binary &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_BINARY_H
+#endif // LIB_SREC_OUTPUT_FILE_BINARY_H
