@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_C_H
-#define INCLUDE_SREC_OUTPUT_FILE_C_H
+#ifndef LIB_SREC_OUTPUT_FILE_C_H
+#define LIB_SREC_OUTPUT_FILE_C_H
 
 #include <lib/srec/output/file.h>
 #include <lib/interval.h>
@@ -44,7 +44,7 @@ private:
       *     The file name to open to write data to.  The name "-" is
       *     understood to mean the standard output.
       */
-    srec_output_file_c(const string &file_name);
+    srec_output_file_c(const std::string &file_name);
 
 public:
     /**
@@ -81,7 +81,7 @@ private:
       * The prefix instance variable is used to remember the variable
       * name prefix to be used in the output.
       */
-    string prefix;
+    std::string prefix;
 
     /**
       * The taddr instance variable is used to remember the
@@ -142,7 +142,7 @@ private:
       * The include_file_name instance variable is used to remember the
       * name of the include file to be generated.
       */
-    string include_file_name;
+    std::string include_file_name;
 
     /**
       * The output_word instance variable is used to remember whether or not
@@ -194,7 +194,7 @@ private:
       * @param addr
       *     The adress to be formatted
       */
-    string format_address(unsigned long addr);
+    std::string format_address(unsigned long addr);
 
     /**
       * The default constructor.  Do not use.
@@ -212,4 +212,4 @@ private:
     srec_output_file_c &operator=(const srec_output_file_c &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_C_H
+#endif // LIB_SREC_OUTPUT_FILE_C_H
