@@ -87,7 +87,7 @@ srec_output_file_cosmac::write(const srec_record &record)
         }
         break;
 
-    case srec_record::type_start_address:
+    case srec_record::type_execution_start_address:
         if (column != 0)
         {
             put_char('\n');
