@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_DEC_BINARY_H
-#define INCLUDE_SREC_OUTPUT_FILE_DEC_BINARY_H
+#ifndef LIB_SREC_OUTPUT_FILE_DEC_BINARY_H
+#define LIB_SREC_OUTPUT_FILE_DEC_BINARY_H
 
 #include <lib/srec/output/file.h>
 
@@ -70,9 +70,6 @@ protected:
     // See base class for documentation.
     void address_length_set(int);
 
-    // See base class for documentation.
-    const char *mode() const;
-
     // See base class for documentation.
     const char *format_name() const;
 
@@ -128,4 +125,4 @@ private:
             const srec_output_file_dec_binary &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_DEC_BINARY_H
+#endif // LIB_SREC_OUTPUT_FILE_DEC_BINARY_H
