@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_EMON52_H
-#define INCLUDE_SREC_OUTPUT_FILE_EMON52_H
+#ifndef LIB_SREC_OUTPUT_FILE_EMON52_H
+#define LIB_SREC_OUTPUT_FILE_EMON52_H
 
 #include <lib/srec/output/file.h>
 
@@ -104,4 +104,4 @@ private:
     srec_output_file_emon52 &operator=(const srec_output_file_emon52 &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_EMON52_H
+#endif // LIB_SREC_OUTPUT_FILE_EMON52_H
