@@ -105,7 +105,7 @@ srec_output_file_fairchild::write(const srec_record &record)
         }
         break;
 
-    case srec_record::type_start_address:
+    case srec_record::type_execution_start_address:
         put_string("*\n");
         break;
     }
