@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_FAIRCHILD_H
-#define INCLUDE_SREC_OUTPUT_FILE_FAIRCHILD_H
+#ifndef LIB_SREC_OUTPUT_FILE_FAIRCHILD_H
+#define LIB_SREC_OUTPUT_FILE_FAIRCHILD_H
 
 #include <lib/srec/output/file.h>
 
@@ -108,4 +108,4 @@ private:
     srec_output_file_fairchild &operator=(const srec_output_file_fairchild &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_FAIRCHILD_H
+#endif // LIB_SREC_OUTPUT_FILE_FAIRCHILD_H
