@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_FASTLOAD_H
-#define INCLUDE_SREC_OUTPUT_FILE_FASTLOAD_H
+#ifndef LIB_SREC_OUTPUT_FILE_FASTLOAD_H
+#define LIB_SREC_OUTPUT_FILE_FASTLOAD_H
 
 #include <lib/srec/output/file.h>
 
@@ -150,4 +150,4 @@ private:
     srec_output_file_fastload &operator=(const srec_output_file_fastload &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_FASTLOAD_H
+#endif // LIB_SREC_OUTPUT_FILE_FASTLOAD_H
