@@ -41,6 +41,8 @@ srec_output_file_formatted_binary::srec_output_file_formatted_binary(
     address(0),
     check_sum(0)
 {
+    if (line_termination == line_termination_native)
+        line_termination = line_termination_binary;
 }
 
 
@@ -124,8 +126,8 @@ srec_output_file_formatted_binary::write(const srec_record &record)
         }
         break;
 
-    case srec_record::type_start_address:
-        // This format can't do start address records
+    case srec_record::type_execution_start_address:
+        // This format can't do execution start address records
         break;
 
     case srec_record::type_unknown:
@@ -136,14 +138,6 @@ srec_output_file_formatted_binary::write(const srec_record &record)
 }
 
 
-const char *
-srec_output_file_formatted_binary::mode()
-    const
-{
-    return "wb";
-}
-
-
 void
 srec_output_file_formatted_binary::line_length_set(int)
 {
