@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_FOUR_PACKED_CODE_H
-#define INCLUDE_SREC_OUTPUT_FILE_FOUR_PACKED_CODE_H
+#ifndef LIB_SREC_OUTPUT_FILE_FOUR_PACKED_CODE_H
+#define LIB_SREC_OUTPUT_FILE_FOUR_PACKED_CODE_H
 
 #include <lib/srec/output/file.h>
 
@@ -127,4 +127,4 @@ private:
         const srec_output_file_four_packed_code &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_FOUR_PACKED_CODE_H
+#endif // LIB_SREC_OUTPUT_FILE_FOUR_PACKED_CODE_H
