@@ -151,7 +151,7 @@ srec_output_file_hexdump::write(const srec_record &record)
         }
         break;
 
-    case srec_record::type_start_address:
+    case srec_record::type_execution_start_address:
         // ignore
         break;
     }
