@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 1998, 1999, 2001-2003, 2006-2008 Peter Miller
+//      Copyright (C) 1998, 1999, 2001-2003, 2006-2009 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 srec_output_file_intel::~srec_output_file_intel()
 {
-    if (!data_only_flag)
+    if (enable_footer_flag)
         write_inner(1, 0L, 0, 0);
 }
 
@@ -89,6 +89,42 @@ srec_output_file_intel::write(const srec_record &record)
         break;
 
     case srec_record::type_data:
+        //
+        // Segmented mode has an ugly boundary condition.
+        //
+        if (mode != linear)
+        {
+            //
+            // If the record would cross a segment boundary, split the
+            // record across the boundary.  This avoids an ambiguity in
+            // the Intel spec.
+            //
+            srec_record::address_t begin_segment = record.get_address() >> 16;
+            srec_record::address_t end_segment =
+                (record.get_address() + record.get_length() - 1) >> 16;
+            if (begin_segment != end_segment)
+            {
+                int split = (1L << 16) - (record.get_address() & 0xFFFF);
+                srec_record part1
+                (
+                    srec_record::type_data,
+                    record.get_address(),
+                    record.get_data(),
+                    split
+                );
+                write(part1);
+                srec_record part2
+                (
+                    srec_record::type_data,
+                    record.get_address() + split,
+                    record.get_data() + split,
+                    record.get_length() - split
+                );
+                write(part2);
+                return;
+            }
+        }
+
         if ((record.get_address() & 0xFFFF0000) != address_base)
         {
             address_base = record.get_address() & 0xFFFF0000;
@@ -125,11 +161,12 @@ srec_output_file_intel::write(const srec_record &record)
         // ignore
         break;
 
-    case srec_record::type_start_address:
-        if (data_only_flag)
-            break;
-        srec_record::encode_big_endian(tmp, record.get_address(), 4);
-        write_inner((mode == linear ? 5 : 3), 0L, tmp, 4);
+    case srec_record::type_execution_start_address:
+        if (enable_goto_addr_flag)
+        {
+            srec_record::encode_big_endian(tmp, record.get_address(), 4);
+            write_inner((mode == linear ? 5 : 3), 0L, tmp, 4);
+        }
         break;
 
     case srec_record::type_unknown:
