@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_INTEL16_H
-#define INCLUDE_SREC_OUTPUT_FILE_INTEL16_H
+#ifndef LIB_SREC_OUTPUT_FILE_INTEL16_H
+#define LIB_SREC_OUTPUT_FILE_INTEL16_H
 
 #include <lib/srec/output/file.h>
 
@@ -107,4 +107,4 @@ private:
     srec_output_file_intel16 &operator=(const srec_output_file_intel16 &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_INTEL16_H
+#endif // LIB_SREC_OUTPUT_FILE_INTEL16_H
