@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_NEEDHAM_H
-#define INCLUDE_SREC_OUTPUT_FILE_NEEDHAM_H
+#ifndef LIB_SREC_OUTPUT_FILE_NEEDHAM_H
+#define LIB_SREC_OUTPUT_FILE_NEEDHAM_H
 
 #include <lib/srec/output/file.h>
 
@@ -113,4 +113,4 @@ private:
     srec_output_file_needham &operator=(const srec_output_file_needham &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_NEEDHAM_H
+#endif // LIB_SREC_OUTPUT_FILE_NEEDHAM_H
