@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_OS65V_H
-#define INCLUDE_SREC_OUTPUT_FILE_OS65V_H
+#ifndef LIB_SREC_OUTPUT_FILE_OS65V_H
+#define LIB_SREC_OUTPUT_FILE_OS65V_H
 
 #include <lib/srec/output/file.h>
 
@@ -90,10 +90,10 @@ private:
 
     /**
       * The seen_start_address instance variable is used to remember
-      * whether or not a start address has been seen.  Normally this
-      * is only given at the end of data.  This variable is used to
-      * determine whether to emit thre "return to monitor" sequence,
-      * if a "GO" command has not been issued.
+      * whether or not an execution start address has been seen.
+      * Normally this is only given at the end of data.  This variable
+      * is used to determine whether to emit thre "return to monitor"
+      * sequence, if a "GO" command has not been issued.
       */
     bool seen_start_address;
 
@@ -113,4 +113,4 @@ private:
     srec_output_file_os65v &operator=(const srec_output_file_os65v &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_OS65V_H
+#endif // LIB_SREC_OUTPUT_FILE_OS65V_H
