@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_SIGNETICS_H
-#define INCLUDE_SREC_OUTPUT_FILE_SIGNETICS_H
+#ifndef LIB_SREC_OUTPUT_FILE_SIGNETICS_H
+#define LIB_SREC_OUTPUT_FILE_SIGNETICS_H
 
 #include <lib/srec/output/file.h>
 
@@ -117,4 +117,4 @@ private:
     srec_output_file_signetics &operator=(const srec_output_file_signetics &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_SIGNETICS_H
+#endif // LIB_SREC_OUTPUT_FILE_SIGNETICS_H
