@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_SRECORD_H
-#define INCLUDE_SREC_OUTPUT_FILE_SRECORD_H
+#ifndef LIB_SREC_OUTPUT_FILE_SRECORD_H
+#define LIB_SREC_OUTPUT_FILE_SRECORD_H
 
 #include <lib/srec/output/file.h>
 
@@ -152,4 +152,4 @@ private:
     srec_output_file_srecord &operator=(const srec_output_file_srecord &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_SRECORD_H
+#endif // LIB_SREC_OUTPUT_FILE_SRECORD_H
