@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_STEWIE_H
-#define INCLUDE_SREC_OUTPUT_FILE_STEWIE_H
+#ifndef LIB_SREC_OUTPUT_FILE_STEWIE_H
+#define LIB_SREC_OUTPUT_FILE_STEWIE_H
 
 #include <lib/srec/output/file.h>
 
@@ -70,9 +70,6 @@ protected:
     // See base class for documentation.
     int preferred_block_size_get() const;
 
-    // See base class for documentation.
-    const char *mode() const;
-
     // See base class for documentation.
     void put_byte(unsigned char);
 
@@ -119,4 +116,4 @@ private:
     srec_output_file_stewie &operator=(const srec_output_file_stewie &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_STEWIE_H
+#endif // LIB_SREC_OUTPUT_FILE_STEWIE_H
