@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_TEKTRONIX_H
-#define INCLUDE_SREC_OUTPUT_FILE_TEKTRONIX_H
+#ifndef LIB_SREC_OUTPUT_FILE_TEKTRONIX_H
+#define LIB_SREC_OUTPUT_FILE_TEKTRONIX_H
 
 #include <lib/srec/output/file.h>
 
@@ -114,4 +114,4 @@ private:
     srec_output_file_tektronix &operator=(const srec_output_file_tektronix &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_TEKTRONIX_H
+#endif // LIB_SREC_OUTPUT_FILE_TEKTRONIX_H
