@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_TI_TAGGED_H
-#define INCLUDE_SREC_OUTPUT_FILE_TI_TAGGED_H
+#ifndef LIB_SREC_OUTPUT_FILE_TI_TAGGED_H
+#define LIB_SREC_OUTPUT_FILE_TI_TAGGED_H
 
 #include <lib/srec/output/file.h>
 
@@ -126,4 +126,4 @@ private:
     srec_output_file_ti_tagged &operator=(const srec_output_file_ti_tagged &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_TI_TAGGED_H
+#endif // LIB_SREC_OUTPUT_FILE_TI_TAGGED_H
