@@ -27,6 +27,11 @@ srec_output_file_ti_tagged_16::~srec_output_file_ti_tagged_16()
 {
     if (column)
         put_eoln();
+    if (enable_footer_flag)
+    {
+        put_char(':');
+        put_char('\n');
+    }
 }
 
 
@@ -82,7 +87,7 @@ srec_output_file_ti_tagged_16::write(const srec_record &record)
     switch (record.get_type())
     {
     case srec_record::type_header:
-        if (!data_only_flag)
+        if (enable_header_flag)
         {
             put_stringf("K%4.4X", 5 + record.get_length());
             const unsigned char *cp = record.get_data();
@@ -146,18 +151,10 @@ srec_output_file_ti_tagged_16::write(const srec_record &record)
         break;
 
     case srec_record::type_data_count:
+    case srec_record::type_execution_start_address:
         // ignore
         break;
 
-    case srec_record::type_start_address:
-        if (column)
-            put_eoln();
-        if (data_only_flag)
-            break;
-        put_char(':');
-        put_char('\n');
-        break;
-
     case srec_record::type_unknown:
         fatal_error("can't write unknown record type");
     }
