@@ -18,8 +18,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_VHDL_H
-#define INCLUDE_SREC_OUTPUT_FILE_VHDL_H
+#ifndef LIB_SREC_OUTPUT_FILE_VHDL_H
+#define LIB_SREC_OUTPUT_FILE_VHDL_H
 
 #include <lib/srec/output/file.h>
 
@@ -88,7 +88,7 @@ private:
       * The prefix instance variable is used to remember the prefix of
       * the various names emitted into the output.
       */
-    string prefix;
+    std::string prefix;
 
     /**
       * The header_done instance variable is used to remember whether
@@ -118,4 +118,4 @@ private:
     srec_output_file_vhdl &operator=(const srec_output_file_vhdl &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_VHDL_H
+#endif // LIB_SREC_OUTPUT_FILE_VHDL_H
