@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_OUTPUT_FILE_WILSON_H
-#define INCLUDE_SREC_OUTPUT_FILE_WILSON_H
+#ifndef LIB_SREC_OUTPUT_FILE_WILSON_H
+#define LIB_SREC_OUTPUT_FILE_WILSON_H
 
 #include <lib/srec/output/file.h>
 
@@ -69,9 +69,6 @@ protected:
     // See base class for documentation.
     int preferred_block_size_get() const;
 
-    // See base class for documentation.
-    const char *mode() const;
-
     // See base class for documentation.
     void put_byte(unsigned char);
 
@@ -117,4 +114,4 @@ private:
     srec_output_file_wilson &operator=(const srec_output_file_wilson &);
 };
 
-#endif // INCLUDE_SREC_OUTPUT_FILE_WILSON_H
+#endif // LIB_SREC_OUTPUT_FILE_WILSON_H
