@@ -17,8 +17,8 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#ifndef INCLUDE_SREC_RECORD_H
-#define INCLUDE_SREC_RECORD_H
+#ifndef LIB_SREC_RECORD_H
+#define LIB_SREC_RECORD_H
 
 #include <lib/endian.h>
 
@@ -45,7 +45,7 @@ public:
         type_header,
         type_data,
         type_data_count,
-        type_start_address
+        type_execution_start_address
     };
 
     /**
@@ -327,4 +327,4 @@ private:
     data_t data[max_data_length];
 };
 
-#endif // INCLUDE_SREC_RECORD_H
+#endif // LIB_SREC_RECORD_H
