@@ -18,10 +18,9 @@
 //
 
 #include <iostream>
-using namespace std;
 #include <cstdlib>
-#include <vector>
 
+#include <lib/srec/input/catenate.h>
 #include <lib/srec/input/file.h>
 #include <lib/srec/memory.h>
 #include <lib/srec/memory/walker/writer.h>
@@ -36,15 +35,14 @@ main(int argc, char **argv)
 {
     srec_cat_arglex3 cmdline(argc, argv);
     cmdline.token_first();
-    typedef vector<srec_input::pointer> infile_t;
-    infile_t infile;
+    srec_input::pointer infile;
     srec_output::pointer outfile;
     int line_length = 0;
     int address_length = 0;
     std::string header;
     bool header_set = false;
-    unsigned long start_address = 0;
-    bool start_address_set = false;
+    unsigned long execution_start_address = 0;
+    bool execution_start_address_set = false;
     while (cmdline.token_cur() != arglex::token_eoln)
     {
         switch (cmdline.token_cur())
@@ -57,7 +55,13 @@ main(int argc, char **argv)
         case srec_arglex::token_string:
         case srec_arglex::token_stdio:
         case srec_arglex::token_generator:
-            infile.push_back(cmdline.get_input());
+            {
+                srec_input::pointer ip = cmdline.get_input();
+                if (infile)
+                    infile = srec_input_catenate::create(infile, ip);
+                else
+                    infile = ip;
+            }
             continue;
 
         case srec_arglex::token_output:
@@ -74,8 +78,8 @@ main(int argc, char **argv)
             line_length = cmdline.value_number();
             if (line_length <= 0)
             {
-                cerr << "the line length " << line_length << " is invalid"
-                    << endl;
+                std::cerr << "the line length " << line_length << " is invalid"
+                    << std::endl;
                 exit(1);
             }
             break;
@@ -88,40 +92,83 @@ main(int argc, char **argv)
             address_length = cmdline.value_number();
             if (address_length <= 0 || address_length > (int)sizeof(long))
             {
-                cerr << "the address length " << address_length
-                    << " is invalid" << endl;
+                std::cerr << "the address length " << address_length
+                    << " is invalid" << std::endl;
                 exit(1);
             }
             break;
 
         case srec_cat_arglex3::token_data_only:
-            srec_output_file::data_only();
+            srec_output_file::enable_header(false);
+            srec_output_file::enable_data_count(false);
+            srec_output_file::enable_goto_addr(false);
+            srec_output_file::enable_footer(false);
             break;
 
+        case srec_cat_arglex3::token_enable:
+        case srec_cat_arglex3::token_disable:
+            {
+                int tok = cmdline.token_cur();
+                bool yesno = (tok == srec_cat_arglex3::token_enable);
+                cmdline.token_next();
+                std::string name = cmdline.get_string(cmdline.token_name(tok));
+                if (!srec_output_file::enable_by_name(name, yesno))
+                {
+                    std::cerr << "argument of " << cmdline.token_name(tok)
+                        << "=" << name << " unknown" << std::endl;
+                    cmdline.usage();
+                }
+            }
+            continue;
+
         case srec_cat_arglex3::token_crlf:
-            srec_output_file::crlf();
+            srec_output_file::line_termination_by_name("crlf");
             break;
 
+        case srec_cat_arglex3::token_line_termination:
+            {
+                int tok = cmdline.token_cur();
+                cmdline.token_next();
+                std::string name = cmdline.get_string(cmdline.token_name(tok));
+                if (!srec_output_file::line_termination_by_name(name))
+                {
+                    std::cerr << "line termination \"" << name << "\" unknown"
+                        << std::endl;
+                    cmdline.usage();
+                }
+            }
+            continue;
+
         case srec_cat_arglex3::token_header:
             if (cmdline.token_next() != arglex::token_string)
             {
-                cerr << "the header option requires a string argument" << endl;
+                std::cerr << "the header option requires a string argument"
+                    << std::endl;
                 exit(1);
             }
             header = cmdline.value_string();
             header_set = true;
+            srec_output_file::enable_header(true);
             break;
 
-        case srec_cat_arglex3::token_start_address:
+        case srec_cat_arglex3::token_execution_start_address:
+            if (execution_start_address_set)
+            {
+                std::cerr << "too many -execution-start-address options "
+                    "specified" << std::endl;
+                exit(1);
+            }
             cmdline.token_next();
-            start_address = cmdline.get_number("-Start_Address");
-            start_address_set = true;
+            execution_start_address =
+                cmdline.get_number("-Execution_Start_Address");
+            execution_start_address_set = true;
+            srec_output_file::enable_goto_addr(true);
             continue;
         }
         cmdline.token_next();
     }
-    if (infile.size() == 0)
-        infile.push_back(cmdline.get_input());
+    if (!infile)
+        infile = cmdline.get_input();
     if (!outfile)
         outfile = cmdline.get_output();
     if (address_length > 0)
@@ -136,19 +183,15 @@ main(int argc, char **argv)
     //
     // It is assumed the data will all fit into memory.  This is
     // usually reasonable, because these utilities are used for
-    // eproms which are usually smaller than the available virtual
+    // EPROMs which are usually smaller than the available virtual
     // memory of the development system.
     //
     srec_memory m;
     if (header_set)
         m.set_header(header.c_str());
-    for (infile_t::iterator it = infile.begin(); it != infile.end(); ++it)
-    {
-        srec_input::pointer ifp = *it;
-        m.reader(ifp, true);
-    }
-    if (start_address_set)
-        m.set_start_address(start_address);
+    m.reader(infile, true);
+    if (execution_start_address_set)
+        m.set_execution_start_address(execution_start_address);
 
     //
     // Open the output file and write the remembered data out to it.
